@@ -1,7 +1,7 @@
 /*
- * Copyright 2004-2008 J. Dahl and L. Vandenberghe.
+ * Copyright 2004-2009 J. Dahl and L. Vandenberghe.
  *
- * This file is part of CVXOPT version 1.1.
+ * This file is part of CVXOPT version 1.1.2
  *
  * CVXOPT is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,9 +21,11 @@
 #include "structmember.h"
 #include "blas_redefines.h"
 
+#include "assert.h"
+
 /* ANSI99 complex is disabled during build of CHOLMOD */
 
-#ifndef NO_ANSI99_COMPLEX 
+#ifndef NO_ANSI99_COMPLEX
 #include "complex.h"
 #define MAT_BUFZ(O)  ((complex *)((matrix *)O)->buffer)
 #endif
@@ -34,11 +36,11 @@
 /*
 static void * malloc_aligned(size_t size) {
   void *p = NULL;
-  if (!posix_memalign(&p, 16, size)) 
+  if (!posix_memalign(&p, 16, size))
     return p;
-  else 
-    return NULL;      
-} 
+  else
+    return NULL;
+}
 
 #define malloc(size) malloc_aligned(size)
 */
@@ -52,7 +54,7 @@ static void * malloc_aligned(size_t size) {
 typedef struct {
   PyObject_HEAD
   void *buffer;          /* in column-major-mode array of type 'id' */
-  int   nrows, ncols;    /* number of rows and columns */
+  int_t nrows, ncols;    /* number of rows and columns */
   int   id;              /* DOUBLE, INT, COMPLEX */
 } matrix;
 
@@ -71,23 +73,23 @@ typedef struct {
 
 #ifdef BASE_MODULE
 
-#define Matrix_Check(v) ((v)->ob_type == &matrix_tp) 
-#define SpMatrix_Check(v) ((v)->ob_type == &spmatrix_tp) 
+#define Matrix_Check(v) ((v)->ob_type == &matrix_tp)
+#define SpMatrix_Check(v) ((v)->ob_type == &spmatrix_tp)
 
 #else
 
 static void **cvxopt_API;
 
-#define Matrix_New (*(matrix * (*)(int, int, int)) cvxopt_API[0])
+#define Matrix_New (*(matrix * (*)(int_t, int_t, int)) cvxopt_API[0])
 #define Matrix_NewFromMatrix (*(matrix * (*)(matrix *, int)) cvxopt_API[1])
 #define Matrix_NewFromList (*(matrix * (*)(PyObject *, int)) cvxopt_API[2])
 #define Matrix_Check (*(int * (*)(void *)) cvxopt_API[3])
 
-#define SpMatrix_New (*(spmatrix * (*)(int, int, int, int)) cvxopt_API[4])
+#define SpMatrix_New (*(spmatrix * (*)(int_t, int_t, int_t, int)) cvxopt_API[4])
 #define SpMatrix_NewFromSpMatrix \
   (*(spmatrix * (*)(spmatrix *, int)) cvxopt_API[5])
 #define SpMatrix_NewFromIJV \
-  (*(spmatrix * (*)(matrix *, matrix *, matrix *, int, int, int)) \
+  (*(spmatrix * (*)(matrix *, matrix *, matrix *, int_t, int_t, int)) \
       cvxopt_API[6])
 #define SpMatrix_Check (*(int * (*)(void *)) cvxopt_API[7])
 
@@ -96,7 +98,7 @@ static int
 import_cvxopt(void)
 {
   PyObject *module = PyImport_ImportModule("cvxopt.base");
-    
+
   if (module != NULL) {
     PyObject *c_api_object = PyObject_GetAttrString(module, "_C_API");
     if (c_api_object == NULL)
@@ -111,16 +113,16 @@ import_cvxopt(void)
 #endif
 
 /*
- * Below this line are non-essential convenience macros 
+ * Below this line are non-essential convenience macros
  */
 
 #define MAT_BUF(O)   ((matrix *)O)->buffer
-#define MAT_BUFI(O)  ((int_t *)((matrix *)O)->buffer) 
+#define MAT_BUFI(O)  ((int_t *)((matrix *)O)->buffer)
 #define MAT_BUFD(O)  ((double *)((matrix *)O)->buffer)
 #define MAT_BUFZ(O)  ((complex *)((matrix *)O)->buffer)
 
-#define MAT_NROWS(O) ((matrix *)O)->nrows 
-#define MAT_NCOLS(O) ((matrix *)O)->ncols 
+#define MAT_NROWS(O) ((matrix *)O)->nrows
+#define MAT_NCOLS(O) ((matrix *)O)->ncols
 #define MAT_LGT(O)   (MAT_NROWS(O)*MAT_NCOLS(O))
 #define MAT_ID(O)    ((matrix *)O)->id
 
@@ -128,7 +130,7 @@ import_cvxopt(void)
 #define SP_NROWS(O)  ((spmatrix *)O)->obj->nrows
 #define SP_LGT(O)    (SP_NROWS(O)*SP_NCOLS(O))
 #define SP_NNZ(O)    ((spmatrix *)O)->obj->colptr[SP_NCOLS(O)]
-#define SP_ID(O)     ((spmatrix *)O)->obj->id    
+#define SP_ID(O)     ((spmatrix *)O)->obj->id
 #define SP_COL(O)    ((spmatrix *)O)->obj->colptr
 #define SP_ROW(O)    ((spmatrix *)O)->obj->rowind
 #define SP_VAL(O)    ((spmatrix *)O)->obj->values
@@ -139,4 +141,4 @@ import_cvxopt(void)
 #define CCS_NCOLS(O) ((ccs *)O)->ncols
 #define CCS_NNZ(O)   ((ccs *)O)->colptr[CCS_NCOLS(O)]
 
-#endif 
+#endif
