@@ -5,9 +5,9 @@ Routines for specifying and solving convex optimization problems with
 piecewise-linear objective and constraint functions.
 """
 
-# Copyright 2004-2008 J. Dahl and L. Vandenberghe.
+# Copyright 2004-2009 J. Dahl and L. Vandenberghe.
 # 
-# This file is part of CVXOPT version 1.1.
+# This file is part of CVXOPT version 1.1.2
 #
 # CVXOPT is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -2380,7 +2380,7 @@ class op(object):
 
                 for j in xrange(len(fk._flist)):
                     c = fk._flist[j] <= tk
-                    if xrange(len(fk._flist)) > 1:
+                    if len(fk._flist) > 1:
                         c.name = self.name + '[%d](%d)' %(k,j)
                     else:
                         c.name = self.name + '[%d]' %k
